import { Component, EventEmitter, ViewEncapsulation, ApplicationRef, trigger, animate, state, style, transition, Input, Output } from '@angular/core';
import Dropdown from 'angular2-dropdown';
@Component({
    selector: 'cvd-date-chooser',
    template: `
    <div>
        <div class="h4"><ng-content></ng-content></div>
        <cvd-dropdown (change)="onChange($event, 'month')" [selection]="month" [data]="months"></cvd-dropdown>
        <cvd-dropdown (change)="onChange($event, 'day')" [selection]="day" [data]="days"></cvd-dropdown>
        <cvd-dropdown (change)="onChange($event, 'year')" [selection]="yearIndex" [data]="years"></cvd-dropdown>
    </div>
    `,
    directives: [Dropdown]
})
export default class DateChooser {
    private months = [
        "January",
        "February",
        "March",
        "April",
        "May",
        "June",
        "July",
        "August",
        "September",
        "October",
        "November",
        "December"
    ];
    private daysInMonth = [
        31, // Jan
        28, // Feb
        31, // March
        30, // April
        31, // May
        30, // June
        31, // July
        31, // August
        30, // September
        31, // October
        30, // November
        31 // December
    ];
    private days = [...Array(31).keys()].map(x => x+1); //ES6 beauty [1,2,...31]
    private years = [...Array(5).keys()].map(x => new Date().getFullYear() - x);

    private month: number;
    private day: number;
    private year: number;
    private yearIndex: number;

    @Input("date") date: Date;
    @Output("change") changed = new EventEmitter();

    ngOnChanges() {
        if (this.date) {
            this.month = this.date.getMonth();
            this.day = this.date.getDate() - 1;
            this.year = this.date.getFullYear();
            this.yearIndex = this.years.indexOf(this.date.getFullYear());

            this.days = [...Array(this.daysInMonth[this.month]).keys()].map(x => x + 1);
        }
    }

    onClick(value, type) {

    }

    onChange(value, type) {
        switch (type) {
            case 'month':
                this.month = value.index;
                this.days = [...Array(this.daysInMonth[this.month]).keys()].map(x => x + 1);
                break;
            case 'day':
                this.day = value.index;
                break;
            case 'year':
                this.year = this.years[value.index];
                break;
            default:
                break;
        }

        let d = new Date();
        d.setDate(this.day + 1);
        d.setMonth(this.month);
        d.setFullYear(this.year);

        if (value.type !== 'initial')
            this.changed.emit(d);
    }
}